==> guswds-5.2.4.tar.gz: guswds/source/04-components/button/button.stories.jsx <==
import parse from 'html-react-parser';

import { withGlobalWrapper } from '../../../.storybook/decorators';
import twigTemplate from './button.twig';
import globalData from '../../00-config/storybook.global-data.yml';
import data from './button.yml';

const settings = {
  title: 'Components/Button',
  decorators: [withGlobalWrapper],
  argTypes: {
    icon_name: {
      options: [
        false,
        'angle',
        'angles',
        'arrow',
        'arrow-long',
        'bars',
        'calendar',
        'caret',
        'check',
        'chevron',
        'download',
        'ellipsis',
        'envelope',
        'file',
        'magnifying-glass',
        'minus',
        'plus',
        'rss',
        'square',
        'square-check',
        'square-empty',
        'xmark',
        'facebook',
        'instagram',
        'linkedin',
        'twitter',
        'youtube',
      ],
      control: { type: 'select' },
    },
    icon_direction: {
      options: ['up', 'right', 'down', 'left'],
      control: { type: 'select' },
    },
    icon_position: {
      options: ['before', 'after', 'both'],
      control: { type: 'select' },
    },
    icon_is_hidden: {
      control: { type: 'boolean' },
    },
  },
  parameters: {
    controls: {
      include: [
        'text',
        'text_demo',
        'is_disabled',
        'button_type',
        'modifier_classes',
        'extra_attributes',
        'icon_name',
        'icon_direction',
        'icon_position',
        'icon_label',
        'icon_is_hidden',
      ],
    },
  },
};

const Default = args =>
  parse(
    twigTemplate({
      ...args,
    })
  );
Default.args = { ...globalData, ...data };

const Secondary = args =>
  parse(
    twigTemplate({
      ...args,
      modifier_classes: 'c-button--secondary',
    })
  );
Secondary.args = { ...globalData, ...data };

const Outline = args =>
  parse(
    twigTemplate({
      ...args,
      modifier_classes: 'c-button--outline',
    })
  );
Outline.args = { ...globalData, ...data };

const Danger = args =>
  parse(
    twigTemplate({
      ...args,
      modifier_classes: 'c-button--danger',
    })
  );
Danger.args = { ...globalData, ...data };

const Small = args =>
  parse(
    twigTemplate({
      ...args,
      modifier_classes: 'c-button--small',
    })
  );
Small.args = { ...globalData, ...data };

const Large = args =>
  parse(
    twigTemplate({
      ...args,
      modifier_classes: 'c-button--large',
    })
  );
Large.args = { ...globalData, ...data };

export default settings;
export { Default, Secondary, Outline, Danger, Small, Large };

==> guswds-5.2.6.tar.gz: guswds/source/04-components/button/button.stories.jsx <==
import parse from 'html-react-parser';

import { withGlobalWrapper } from '../../../.storybook/decorators';
import twigTemplate from './button.twig';
import globalData from '../../00-config/storybook.global-data.yml';
import data from './button.yml';

const settings = {
  title: 'Components/Button',
  decorators: [
    (Story, {args}) =>
      <>
        <Story />
        <Story args={{ ...args, is_button_tag: false, text: 'Link Button' }} />
        <Story args={{ ...args, is_disabled: true, text: 'Disabled Button' }} />
      </>, withGlobalWrapper],
  argTypes: {
    icon_name: {
      options: [ false, ...globalData.icons ],
      control: { type: 'select' },
    },
    icon_direction: {
      options: ['up', 'right', 'down', 'left'],
      control: { type: 'select' },
    },
    icon_position: {
      options: ['before', 'after', 'both'],
      control: { type: 'select' },
    },
    icon_is_hidden: {
      control: { type: 'boolean' },
    },
  },
  parameters: {
    controls: {
      include: [
        'text',
        'is_disabled',
        'button_type',
        'modifier_classes',
        'extra_attributes',
        'icon_name',
        'icon_direction',
        'icon_position',
        'icon_label',
        'icon_is_hidden',
      ],
    },
  },
};

const Default = args =>
  parse(
    twigTemplate({
      ...args,
    })
  );
Default.args = { ...globalData, ...data };

const Secondary = args =>
  parse(
    twigTemplate({
      ...args,
    })
  );
Secondary.args = { ...globalData, ...data, modifier_classes: 'c-button--secondary', };

const Outline = args =>
  parse(
    twigTemplate({
      ...args,
    })
  );
Outline.args = { ...globalData, ...data, modifier_classes: 'c-button--outline', };

const Danger = args =>
  parse(
    twigTemplate({
      ...args,
    })
  );
Danger.args = { ...globalData, ...data, modifier_classes: 'c-button--danger', };

const Small = args =>
  parse(
    twigTemplate({
      ...args,
    })
  );
Small.args = { ...globalData, ...data, modifier_classes: 'c-button--small', };

const Large = args =>
  parse(
    twigTemplate({
      ...args,
    })
  );
Large.args = { ...globalData, ...data };
Large.args = { ...globalData, ...data, modifier_classes: 'c-button--large', };

export default settings;
export { Default, Secondary, Outline, Danger, Small, Large };
